---
pageType: home

hero:
  name: hs-config
  text: 更灵活优雅的配置你的Python项目
  tagline: 多格式、灵活、优雅、基于Pydantic
  actions:
    - theme: brand
      text: 快速开始
      link: /guide/start/introduction
    - theme: alt
      text: GitHub
      link: https://github.com/web-infra-dev/rspress
  image:
    src: /rspress-icon.png
    alt: HsConfigDocs Logo
features:
  - title: 多格式
    details: 同时支持json、tom、yaml、ini、环境变量、.env文件等多种格式
    icon: 🏃🏻‍♀️
  - title: 强类型校验
    details: 基于`Pydantic`的pydantic-settings实现，自带类型校验
    icon: 📦
  - title: 便于使用
    details: 只需继承至`SettingsBase`后，创建`setting对象`即可使用
    icon: 🎨
  - title: 多环境配置（待开发）
    details: 通过参数灵活选择开发环境、测试环境、线上环境
    icon: 🌍
  - title: 不知道写啥了
    details: 不知道写啥了，空着怪丑的
    icon: 🌈
  - title: 不知道写啥了
    details: 不知道写啥了，空着怪丑的
    icon: 🔥
---
